# $Revision: 1.15 $, $Date: 2010/06/06 01:00:29 $
Summary:	ZFS Filesystem for FUSE/Linux
Summary(pl.UTF-8):	System plików ZFS dla Linuksa z FUSE
Name:		zfs-fuse
Version:	0.5.0
Release:	2
License:	CCDL 1.0
Group:		Applications/Emulators
Source0:	http://download.berlios.de/zfs-fuse/%{name}-%{version}.tar.bz2
# Source0-md5:	46d6bd429d6d9ddd57e078f5f22fa1cd
Source1:	%{name}.init
Patch0:		%{name}-ztest_path.patch
Patch1:		%{name}-libzfs_build.patch
URL:		http://www.wizy.org/wiki/ZFS_on_FUSE
BuildRequires:	libaio-devel
BuildRequires:	libfuse-devel
BuildRequires:	rpmbuild(macros) >= 1.337
BuildRequires:	scons
ExclusiveArch:	%{ix86} %{x8664}
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
ZFS has many features which can benefit all kinds of users - from the
simple end-user to the biggest enterprise systems. ZFS list of
features:
- Provable integrity - it checksums all data (and meta-data), which
  makes it possible to detect hardware errors (hard disk corruption,
  flaky IDE cables...).
- Atomic updates - means that the on-disk state is consistent at all
  times, there's no need to perform a lengthy filesystem check after
  forced reboots/power failures.
- Instantaneous snapshots and clones - it makes it possible to have
  hourly, daily and weekly backups efficiently, as well as experiment
  with new system configurations without any risks.
- Built-in (optional) compression
- Highly scalable
- Pooled storage model - creating filesystems is as easy as creating a
  new directory. You can efficiently have thousands of filesystems, each
  with it's own quotas and reservations, and different properties
  (compression algorithm, checksum algorithm, etc..).
- Built-in stripes (RAID-0), mirrors (RAID-1) and RAID-Z (it's like
  software RAID-5, but more efficient due to ZFS's copy-on-write
  transactional model).
- Among others (variable sector sizes, adaptive endianness, ...)

%description -l pl.UTF-8
ZFS ma wiele możliwości, które mogą zadowolić wielu użytkowników - od
zwykłych użytkowników końcowych do największych systemów
korporacyjnych. Oto lista możliwości:
- kontrolowana integralność - wszystkie dane (i metadane) mają
  obliczane sumy kontrole, które umożliwiają wykrywanie błędów
  sprzętowych (uszkodzeń twardych dysków, niesprawnych kabli IDE).
- atomowe uaktualnienia - stan na dysku zawsze jest spójny, nie ma
  potrzeby wykonywania długiego sprawdzania systemu plików po
  wymuszonych rebootach czy utracie zasilania.
- natychmiastowe migawki i kopie - można mieć godzinne, dzienne i
  tygodniowe kopie zapasowe w sposób wydajny, a także eksperymentować z
  nowymi konfiguracjami systemu plików bez żadnego ryzyka.
- wbudowana (opcjonalna) kompresja
- duża skalowalność
- model przechowywania danych oparty na pulach - tworzenie systemu
  plików jest tak łatwe, jak utworzenie nowego katalogu. Można w sposób
  wydajny mieć tysiące systemów plików, każdy z nich z własnymi
  ograniczeniami (quotą) i rezerwacjami oraz różnymi właściwościami
  (algorytmem kompresji, algorytmem sum kontrolnych itp.).
- wbudowany RAID-0 (striping), RAID-1 (mirroring) i RAID-Z (podobny do
  programowego RAID-5, ale bardziej wydajny dzięki modelowi
  transakcyjnemu ZFS-a z kopiowaniem przy zapisie (copy-on-write)).
- wiele innych (różne rozmiary sektora, adaptacyjna kolejność bajtów w
  słowie...).

%prep
%setup -q
%patch0 -p1
%patch1 -p1
sed -i -e 's#-Werror##g' src/SConstruct

%build
cd src
%scons \
	%{!?debug:dist=1} \
	CCFLAGS="%{rpmcflags}" \
	CC="%{__cc}"

%install
rm -rf $RPM_BUILD_ROOT

cd src
%scons install \
	install_dir=$RPM_BUILD_ROOT%{_bindir}

install -d $RPM_BUILD_ROOT/etc/rc.d/init.d
install %{SOURCE1} $RPM_BUILD_ROOT/etc/rc.d/init.d/zfs-fuse

%clean
rm -rf $RPM_BUILD_ROOT

%post
/sbin/chkconfig --add %{name}
%service %{name} restart

%preun
if [ "$1" = "0" ]; then
%service -q %{name} stop
/sbin/chkconfig --del %{name}
fi

%files
%defattr(644,root,root,755)
%doc BUGS CHANGES HACKING INSTALL LICENSE README STATUS TESTING TODO
%attr(754,root,root) /etc/rc.d/init.d/%{name}
%attr(755,root,root) %{_bindir}/*

%define date	%(echo `LC_ALL="C" date +"%a %b %d %Y"`)
%changelog
* %{date} PLD Team <feedback@pld-linux.org>
All persons listed below can be reached at <cvs_login>@pld-linux.org

$Log: zfs-fuse.spec,v $
Revision 1.15  2010/06/06 01:00:29  arvenil
- added -libzfs_build.patch
- release 2

Revision 1.14  2008/09/16 13:31:48  paszczus
- added zfs-fuse-ztest_path.patch

Revision 1.13  2008/09/16 12:57:29  paszczus
- added zfs-fuse.init script

Revision 1.12  2008/09/16 12:00:55  paszczus
- hurray! we got final 0.5.0

Revision 1.11  2008/09/11 08:59:58  paszczus
- well, it is beta2 now

Revision 1.10  2008/09/11 08:56:01  paszczus
- updates to snap 20080911, source uploaded to dropin

Revision 1.9  2008/07/03 08:11:16  adamg
- up to 20080629 snap

Revision 1.8  2007/08/30 21:07:32  wolvverine
- typo

Revision 1.7  2007/07/09 22:18:54  blues
- fixed args added to scons, but it has to be done in a different way

Revision 1.6  2007/07/08 20:54:22  qboosh
- pl

Revision 1.5  2007/06/25 11:04:26  glen
- %scons macro

Revision 1.4  2007/06/25 10:51:21  arekm
- EA: ix86 x8664

Revision 1.3  2007/06/25 10:37:50  arekm
- adapterize

Revision 1.2  2007/06/25 10:26:13  arekm
- license is CCDL 1.0

Revision 1.1  2007/06/25 10:25:06  arekm
- initial
